@@ -9,5 +9,6 @@ simulate_cvd("red", deutanomaly_cvd["8"][[1]])
 ## convert a mixed vector (hex and built-in)
 simulate_cvd(c("green", "#ffc0cb"), protanomaly_cvd["8"][[1]])
 
-## white and black unchanged (white becomes #FEFFFE due to a rounding error)
-simulate_cvd(c("white", "black"), deutanomaly_cvd["2"][[1]])
+## white and black almost unchanged
+## (white becomes #FEFFFE or #FEFEFF due to rounding errors)
+## simulate_cvd(c("white", "black"), deutanomaly_cvd["2"][[1]])
